# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeCloudbenchTaskConfigResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeCloudbenchTaskConfigResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information, including the error codes and the number of entries that are returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeCloudbenchTaskConfigResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCloudbenchTaskConfigResponseBodyData(DaraModel):
    def __init__(
        self,
        archive_folder: str = None,
        bench_cmd: str = None,
        client_jar_path: str = None,
        jar_on_oss: str = None,
        load_cmd: str = None,
        meta_file_name: str = None,
        meta_file_on_oss: str = None,
        meta_file_path: str = None,
        parse_cmd: str = None,
        parse_file_path: str = None,
        rocks_db_path: str = None,
        sql_file_name: str = None,
        sql_file_on_oss: str = None,
        sql_file_path: str = None,
        task_id: str = None,
        user_id: str = None,
        work_dir: str = None,
    ):
        # The path in which the files are archived.
        self.archive_folder = archive_folder
        # The command that was run to start the stress testing task.
        self.bench_cmd = bench_cmd
        # The path to the JAR file that is used for stress testing.
        self.client_jar_path = client_jar_path
        # The path to the JAR file that is stored in OSS. The JAR file is used for stress testing.
        self.jar_on_oss = jar_on_oss
        # The command that was run to preload the file that stores the analysis result of full SQL statistics.
        self.load_cmd = load_cmd
        # The name of the metadata file.
        self.meta_file_name = meta_file_name
        # The name of the metadata file stored in Object Storage Service (OSS).
        self.meta_file_on_oss = meta_file_on_oss
        # The path to the metadata file.
        self.meta_file_path = meta_file_path
        # The command that was run to parse the file that stores the analysis result of full SQL statistics.
        self.parse_cmd = parse_cmd
        # The path to the file that is parsed. The file stores the analysis result of full SQL statistics.
        self.parse_file_path = parse_file_path
        # The location where the RocksDB storage system is deployed in the stress testing client.
        self.rocks_db_path = rocks_db_path
        # The name of the file that stores the analysis result of full SQL statistics.
        self.sql_file_name = sql_file_name
        # The name of the file that stores the analysis result of full SQL statistics and that is stored in OSS.
        self.sql_file_on_oss = sql_file_on_oss
        # The path to the file that stores the analysis result of full SQL statistics.
        self.sql_file_path = sql_file_path
        # The task ID.
        self.task_id = task_id
        # The Alibaba Cloud account ID.
        self.user_id = user_id
        # The path of the temporary directory that is generated for stress testing.
        self.work_dir = work_dir

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.archive_folder is not None:
            result['ArchiveFolder'] = self.archive_folder

        if self.bench_cmd is not None:
            result['BenchCmd'] = self.bench_cmd

        if self.client_jar_path is not None:
            result['ClientJarPath'] = self.client_jar_path

        if self.jar_on_oss is not None:
            result['JarOnOss'] = self.jar_on_oss

        if self.load_cmd is not None:
            result['LoadCmd'] = self.load_cmd

        if self.meta_file_name is not None:
            result['MetaFileName'] = self.meta_file_name

        if self.meta_file_on_oss is not None:
            result['MetaFileOnOss'] = self.meta_file_on_oss

        if self.meta_file_path is not None:
            result['MetaFilePath'] = self.meta_file_path

        if self.parse_cmd is not None:
            result['ParseCmd'] = self.parse_cmd

        if self.parse_file_path is not None:
            result['ParseFilePath'] = self.parse_file_path

        if self.rocks_db_path is not None:
            result['RocksDbPath'] = self.rocks_db_path

        if self.sql_file_name is not None:
            result['SqlFileName'] = self.sql_file_name

        if self.sql_file_on_oss is not None:
            result['SqlFileOnOss'] = self.sql_file_on_oss

        if self.sql_file_path is not None:
            result['SqlFilePath'] = self.sql_file_path

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.work_dir is not None:
            result['WorkDir'] = self.work_dir

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ArchiveFolder') is not None:
            self.archive_folder = m.get('ArchiveFolder')

        if m.get('BenchCmd') is not None:
            self.bench_cmd = m.get('BenchCmd')

        if m.get('ClientJarPath') is not None:
            self.client_jar_path = m.get('ClientJarPath')

        if m.get('JarOnOss') is not None:
            self.jar_on_oss = m.get('JarOnOss')

        if m.get('LoadCmd') is not None:
            self.load_cmd = m.get('LoadCmd')

        if m.get('MetaFileName') is not None:
            self.meta_file_name = m.get('MetaFileName')

        if m.get('MetaFileOnOss') is not None:
            self.meta_file_on_oss = m.get('MetaFileOnOss')

        if m.get('MetaFilePath') is not None:
            self.meta_file_path = m.get('MetaFilePath')

        if m.get('ParseCmd') is not None:
            self.parse_cmd = m.get('ParseCmd')

        if m.get('ParseFilePath') is not None:
            self.parse_file_path = m.get('ParseFilePath')

        if m.get('RocksDbPath') is not None:
            self.rocks_db_path = m.get('RocksDbPath')

        if m.get('SqlFileName') is not None:
            self.sql_file_name = m.get('SqlFileName')

        if m.get('SqlFileOnOss') is not None:
            self.sql_file_on_oss = m.get('SqlFileOnOss')

        if m.get('SqlFilePath') is not None:
            self.sql_file_path = m.get('SqlFilePath')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('WorkDir') is not None:
            self.work_dir = m.get('WorkDir')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetInstanceMissingIndexListResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetInstanceMissingIndexListResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information.
        self.data = data
        # The returned message.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request is successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetInstanceMissingIndexListResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetInstanceMissingIndexListResponseBodyData(DaraModel):
    def __init__(
        self,
        list: List[main_models.GetInstanceMissingIndexListResponseBodyDataList] = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The returned data.
        self.list = list
        # The page number of the page returned.
        self.page_no = page_no
        # The number of entries per page.
        self.page_size = page_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.GetInstanceMissingIndexListResponseBodyDataList()
                self.list.append(temp_model.from_map(k1))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetInstanceMissingIndexListResponseBodyDataList(DaraModel):
    def __init__(
        self,
        avg_total_user_cost: float = None,
        avg_user_impact: float = None,
        create_index: str = None,
        database_name: str = None,
        equality_columns: str = None,
        included_columns: str = None,
        index_count: int = None,
        inequality_columns: str = None,
        last_user_seek: int = None,
        object_name: str = None,
        reserved_pages: int = None,
        reserved_size: float = None,
        row_count: int = None,
        schema_name: str = None,
        system_scans: int = None,
        system_seeks: int = None,
        unique_compiles: int = None,
        user_scans: int = None,
        user_seeks: int = None,
    ):
        # The average cost savings.
        self.avg_total_user_cost = avg_total_user_cost
        # The performance improvement, in percentage.
        self.avg_user_impact = avg_user_impact
        # The statement used to create the missing indexes.
        self.create_index = create_index
        # The database name.
        self.database_name = database_name
        # The index columns included in the equal operation.
        self.equality_columns = equality_columns
        # The columns on which indexes are missing.
        self.included_columns = included_columns
        # The number of indexes.
        self.index_count = index_count
        # The index columns included in the not equal operation.
        self.inequality_columns = inequality_columns
        # The last seek time of a user.
        self.last_user_seek = last_user_seek
        # The object name.
        self.object_name = object_name
        # The total number of returned pages.
        self.reserved_pages = reserved_pages
        # The table size.
        self.reserved_size = reserved_size
        # The number of table rows.
        self.row_count = row_count
        # The schema name.
        self.schema_name = schema_name
        # The number of scans.
        self.system_scans = system_scans
        # The number of seeks.
        self.system_seeks = system_seeks
        # The number of compilations.
        self.unique_compiles = unique_compiles
        # The number of scans performed by users.
        self.user_scans = user_scans
        # The number of seeks performed by users.
        self.user_seeks = user_seeks

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_total_user_cost is not None:
            result['AvgTotalUserCost'] = self.avg_total_user_cost

        if self.avg_user_impact is not None:
            result['AvgUserImpact'] = self.avg_user_impact

        if self.create_index is not None:
            result['CreateIndex'] = self.create_index

        if self.database_name is not None:
            result['DatabaseName'] = self.database_name

        if self.equality_columns is not None:
            result['EqualityColumns'] = self.equality_columns

        if self.included_columns is not None:
            result['IncludedColumns'] = self.included_columns

        if self.index_count is not None:
            result['IndexCount'] = self.index_count

        if self.inequality_columns is not None:
            result['InequalityColumns'] = self.inequality_columns

        if self.last_user_seek is not None:
            result['LastUserSeek'] = self.last_user_seek

        if self.object_name is not None:
            result['ObjectName'] = self.object_name

        if self.reserved_pages is not None:
            result['ReservedPages'] = self.reserved_pages

        if self.reserved_size is not None:
            result['ReservedSize'] = self.reserved_size

        if self.row_count is not None:
            result['RowCount'] = self.row_count

        if self.schema_name is not None:
            result['SchemaName'] = self.schema_name

        if self.system_scans is not None:
            result['SystemScans'] = self.system_scans

        if self.system_seeks is not None:
            result['SystemSeeks'] = self.system_seeks

        if self.unique_compiles is not None:
            result['UniqueCompiles'] = self.unique_compiles

        if self.user_scans is not None:
            result['UserScans'] = self.user_scans

        if self.user_seeks is not None:
            result['UserSeeks'] = self.user_seeks

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgTotalUserCost') is not None:
            self.avg_total_user_cost = m.get('AvgTotalUserCost')

        if m.get('AvgUserImpact') is not None:
            self.avg_user_impact = m.get('AvgUserImpact')

        if m.get('CreateIndex') is not None:
            self.create_index = m.get('CreateIndex')

        if m.get('DatabaseName') is not None:
            self.database_name = m.get('DatabaseName')

        if m.get('EqualityColumns') is not None:
            self.equality_columns = m.get('EqualityColumns')

        if m.get('IncludedColumns') is not None:
            self.included_columns = m.get('IncludedColumns')

        if m.get('IndexCount') is not None:
            self.index_count = m.get('IndexCount')

        if m.get('InequalityColumns') is not None:
            self.inequality_columns = m.get('InequalityColumns')

        if m.get('LastUserSeek') is not None:
            self.last_user_seek = m.get('LastUserSeek')

        if m.get('ObjectName') is not None:
            self.object_name = m.get('ObjectName')

        if m.get('ReservedPages') is not None:
            self.reserved_pages = m.get('ReservedPages')

        if m.get('ReservedSize') is not None:
            self.reserved_size = m.get('ReservedSize')

        if m.get('RowCount') is not None:
            self.row_count = m.get('RowCount')

        if m.get('SchemaName') is not None:
            self.schema_name = m.get('SchemaName')

        if m.get('SystemScans') is not None:
            self.system_scans = m.get('SystemScans')

        if m.get('SystemSeeks') is not None:
            self.system_seeks = m.get('SystemSeeks')

        if m.get('UniqueCompiles') is not None:
            self.unique_compiles = m.get('UniqueCompiles')

        if m.get('UserScans') is not None:
            self.user_scans = m.get('UserScans')

        if m.get('UserSeeks') is not None:
            self.user_seeks = m.get('UserSeeks')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class ModifySecurityIPGroupResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.ModifySecurityIPGroupResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # ListResult<InstanceSSL>
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.ModifySecurityIPGroupResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class ModifySecurityIPGroupResponseBodyData(DaraModel):
    def __init__(
        self,
        global_security_ipgroup: List[main_models.ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup] = None,
    ):
        self.global_security_ipgroup = global_security_ipgroup

    def validate(self):
        if self.global_security_ipgroup:
            for v1 in self.global_security_ipgroup:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['GlobalSecurityIPGroup'] = []
        if self.global_security_ipgroup is not None:
            for k1 in self.global_security_ipgroup:
                result['GlobalSecurityIPGroup'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.global_security_ipgroup = []
        if m.get('GlobalSecurityIPGroup') is not None:
            for k1 in m.get('GlobalSecurityIPGroup'):
                temp_model = main_models.ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup()
                self.global_security_ipgroup.append(temp_model.from_map(k1))

        return self

class ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup(DaraModel):
    def __init__(
        self,
        gip_list: str = None,
        global_ig_name: str = None,
        global_security_group_id: str = None,
        region_id: str = None,
        security_ip_type: str = None,
        whitelist_net_type: str = None,
    ):
        self.gip_list = gip_list
        self.global_ig_name = global_ig_name
        self.global_security_group_id = global_security_group_id
        self.region_id = region_id
        self.security_ip_type = security_ip_type
        self.whitelist_net_type = whitelist_net_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.gip_list is not None:
            result['GIpList'] = self.gip_list

        if self.global_ig_name is not None:
            result['GlobalIgName'] = self.global_ig_name

        if self.global_security_group_id is not None:
            result['GlobalSecurityGroupId'] = self.global_security_group_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.security_ip_type is not None:
            result['SecurityIpType'] = self.security_ip_type

        if self.whitelist_net_type is not None:
            result['WhitelistNetType'] = self.whitelist_net_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('GIpList') is not None:
            self.gip_list = m.get('GIpList')

        if m.get('GlobalIgName') is not None:
            self.global_ig_name = m.get('GlobalIgName')

        if m.get('GlobalSecurityGroupId') is not None:
            self.global_security_group_id = m.get('GlobalSecurityGroupId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('SecurityIpType') is not None:
            self.security_ip_type = m.get('SecurityIpType')

        if m.get('WhitelistNetType') is not None:
            self.whitelist_net_type = m.get('WhitelistNetType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetSqlOptimizeAdviceResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetSqlOptimizeAdviceResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information, including the error codes and the number of entries that are returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, Successful is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetSqlOptimizeAdviceResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetSqlOptimizeAdviceResponseBodyData(DaraModel):
    def __init__(
        self,
        create_time: str = None,
        download_url: str = None,
        expire_time: str = None,
        status: str = None,
        status_code: str = None,
        task_id: str = None,
    ):
        # The time when the task was created. The value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.create_time = create_time
        # The URL that is used to download the file.
        self.download_url = download_url
        # The time when the file expires. The value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The file expires three days after the task is created.
        self.expire_time = expire_time
        # The status of the task. Valid values:
        # 
        # *   **INIT**: The task is being initialized.
        # *   **RUNNING**: The task is running.
        # *   **FINISH**: The task is complete.
        # *   **FAILED**: The task failed.
        self.status = status
        # The status code of the task. Valid values:
        # 
        # *   **NO_DATA**: No data is returned.
        # *   **INTERNAL_ERROR**: An internal error occurred.
        # *   **SUCCESS**: The task is successful.
        self.status_code = status_code
        # The task ID.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        if self.download_url is not None:
            result['DownloadUrl'] = self.download_url

        if self.expire_time is not None:
            result['ExpireTime'] = self.expire_time

        if self.status is not None:
            result['Status'] = self.status

        if self.status_code is not None:
            result['StatusCode'] = self.status_code

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        if m.get('DownloadUrl') is not None:
            self.download_url = m.get('DownloadUrl')

        if m.get('ExpireTime') is not None:
            self.expire_time = m.get('ExpireTime')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('StatusCode') is not None:
            self.status_code = m.get('StatusCode')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetEndpointSwitchTaskRequest(DaraModel):
    def __init__(
        self,
        task_id: str = None,
        uid: str = None,
        user_id: str = None,
        context: str = None,
        access_key: str = None,
        signature: str = None,
        skip_auth: str = None,
        timestamp: str = None,
    ):
        self.task_id = task_id
        self.uid = uid
        self.user_id = user_id
        self.context = context
        self.access_key = access_key
        self.signature = signature
        self.skip_auth = skip_auth
        self.timestamp = timestamp

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.uid is not None:
            result['Uid'] = self.uid

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.context is not None:
            result['__context'] = self.context

        if self.access_key is not None:
            result['accessKey'] = self.access_key

        if self.signature is not None:
            result['signature'] = self.signature

        if self.skip_auth is not None:
            result['skipAuth'] = self.skip_auth

        if self.timestamp is not None:
            result['timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('Uid') is not None:
            self.uid = m.get('Uid')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('__context') is not None:
            self.context = m.get('__context')

        if m.get('accessKey') is not None:
            self.access_key = m.get('accessKey')

        if m.get('signature') is not None:
            self.signature = m.get('signature')

        if m.get('skipAuth') is not None:
            self.skip_auth = m.get('skipAuth')

        if m.get('timestamp') is not None:
            self.timestamp = m.get('timestamp')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetPartitionsHeatmapRequest(DaraModel):
    def __init__(
        self,
        console_context: str = None,
        instance_id: str = None,
        time_range: str = None,
        type: str = None,
    ):
        # The reserved parameter.
        self.console_context = console_context
        # The instance ID.
        self.instance_id = instance_id
        # The time range to be queried. Valid values:
        # 
        # *   **LAST_ONE_HOURS**: the last hour.
        # *   **LAST_SIX_HOURS**: the last six hours.
        # *   **LAST_ONE_DAYS**: the last day.
        # *   **LAST_THREE_DAYS**: the last three days.
        # *   **LAST_SEVEN_DAYS**: the last seven days.
        self.time_range = time_range
        # The type of the data to be queried. Valid values:
        # 
        # *   **READ_ROWS**: the read rows.
        # *   **WRITTEN_ROWS**: the written rows.
        # *   **READ_WRITTEN_ROWS**: the read and written rows.
        # *   **UPDATE_ROWS**: the updated rows.
        # *   **INSERTED_ROWS**: the inserted rows.
        # *   **DELETED_ROWS**: the deleted rows.
        # *   **READ_ROWS_WITH_DN**: the read rows returned from a data node.
        # *   **WRITTEN_ROWS_WITH_DN**: the written rows returned from a data node.
        # *   **READ_WRITTEN_ROWS_WITH_DN**: the read and written rows returned from a data node.
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.time_range is not None:
            result['TimeRange'] = self.time_range

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('TimeRange') is not None:
            self.time_range = m.get('TimeRange')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeCloudBenchTasksResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeCloudBenchTasksResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information, including the error codes and the number of entries that are returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeCloudBenchTasksResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCloudBenchTasksResponseBodyData(DaraModel):
    def __init__(
        self,
        extra: str = None,
        list: main_models.DescribeCloudBenchTasksResponseBodyDataList = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The reserved parameter.
        self.extra = extra
        self.list = list
        # The page number.
        self.page_no = page_no
        # The number of entries per page.
        self.page_size = page_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            self.list.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.extra is not None:
            result['Extra'] = self.extra

        if self.list is not None:
            result['List'] = self.list.to_map()

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Extra') is not None:
            self.extra = m.get('Extra')

        if m.get('List') is not None:
            temp_model = main_models.DescribeCloudBenchTasksResponseBodyDataList()
            self.list = temp_model.from_map(m.get('List'))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class DescribeCloudBenchTasksResponseBodyDataList(DaraModel):
    def __init__(
        self,
        cloudbench_tasks: List[main_models.DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks] = None,
    ):
        self.cloudbench_tasks = cloudbench_tasks

    def validate(self):
        if self.cloudbench_tasks:
            for v1 in self.cloudbench_tasks:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['cloudbenchTasks'] = []
        if self.cloudbench_tasks is not None:
            for k1 in self.cloudbench_tasks:
                result['cloudbenchTasks'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.cloudbench_tasks = []
        if m.get('cloudbenchTasks') is not None:
            for k1 in m.get('cloudbenchTasks'):
                temp_model = main_models.DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks()
                self.cloudbench_tasks.append(temp_model.from_map(k1))

        return self

class DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks(DaraModel):
    def __init__(
        self,
        archive_job_id: str = None,
        archive_oss_table_name: str = None,
        archive_state: int = None,
        backup_id: str = None,
        backup_type: str = None,
        bench_step: str = None,
        bench_step_status: str = None,
        client_gateway_id: str = None,
        client_type: str = None,
        description: str = None,
        dst_instance_uuid: str = None,
        dst_ip: str = None,
        dst_port: int = None,
        dst_type: str = None,
        dts_job_class: str = None,
        dts_job_id: str = None,
        dts_job_name: str = None,
        dts_job_state: int = None,
        dts_job_status: str = None,
        ecs_instance_id: str = None,
        end_state: str = None,
        error_code: str = None,
        error_message: str = None,
        external: str = None,
        rate: int = None,
        request_duration: int = None,
        smart_pressure_time: int = None,
        source: str = None,
        sql_complete_reuse: str = None,
        src_instance_area: str = None,
        src_instance_uuid: str = None,
        src_public_ip: str = None,
        state: str = None,
        status: str = None,
        table_schema: str = None,
        task_id: str = None,
        task_type: str = None,
        topic: str = None,
        user_id: str = None,
        version: str = None,
        work_dir: str = None,
    ):
        self.archive_job_id = archive_job_id
        self.archive_oss_table_name = archive_oss_table_name
        self.archive_state = archive_state
        self.backup_id = backup_id
        self.backup_type = backup_type
        self.bench_step = bench_step
        self.bench_step_status = bench_step_status
        self.client_gateway_id = client_gateway_id
        self.client_type = client_type
        self.description = description
        self.dst_instance_uuid = dst_instance_uuid
        self.dst_ip = dst_ip
        self.dst_port = dst_port
        self.dst_type = dst_type
        self.dts_job_class = dts_job_class
        self.dts_job_id = dts_job_id
        self.dts_job_name = dts_job_name
        self.dts_job_state = dts_job_state
        self.dts_job_status = dts_job_status
        self.ecs_instance_id = ecs_instance_id
        self.end_state = end_state
        self.error_code = error_code
        self.error_message = error_message
        self.external = external
        self.rate = rate
        self.request_duration = request_duration
        self.smart_pressure_time = smart_pressure_time
        self.source = source
        self.sql_complete_reuse = sql_complete_reuse
        self.src_instance_area = src_instance_area
        self.src_instance_uuid = src_instance_uuid
        self.src_public_ip = src_public_ip
        self.state = state
        self.status = status
        self.table_schema = table_schema
        self.task_id = task_id
        self.task_type = task_type
        self.topic = topic
        self.user_id = user_id
        self.version = version
        self.work_dir = work_dir

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.archive_job_id is not None:
            result['ArchiveJobId'] = self.archive_job_id

        if self.archive_oss_table_name is not None:
            result['ArchiveOssTableName'] = self.archive_oss_table_name

        if self.archive_state is not None:
            result['ArchiveState'] = self.archive_state

        if self.backup_id is not None:
            result['BackupId'] = self.backup_id

        if self.backup_type is not None:
            result['BackupType'] = self.backup_type

        if self.bench_step is not None:
            result['BenchStep'] = self.bench_step

        if self.bench_step_status is not None:
            result['BenchStepStatus'] = self.bench_step_status

        if self.client_gateway_id is not None:
            result['ClientGatewayId'] = self.client_gateway_id

        if self.client_type is not None:
            result['ClientType'] = self.client_type

        if self.description is not None:
            result['Description'] = self.description

        if self.dst_instance_uuid is not None:
            result['DstInstanceUuid'] = self.dst_instance_uuid

        if self.dst_ip is not None:
            result['DstIp'] = self.dst_ip

        if self.dst_port is not None:
            result['DstPort'] = self.dst_port

        if self.dst_type is not None:
            result['DstType'] = self.dst_type

        if self.dts_job_class is not None:
            result['DtsJobClass'] = self.dts_job_class

        if self.dts_job_id is not None:
            result['DtsJobId'] = self.dts_job_id

        if self.dts_job_name is not None:
            result['DtsJobName'] = self.dts_job_name

        if self.dts_job_state is not None:
            result['DtsJobState'] = self.dts_job_state

        if self.dts_job_status is not None:
            result['DtsJobStatus'] = self.dts_job_status

        if self.ecs_instance_id is not None:
            result['EcsInstanceId'] = self.ecs_instance_id

        if self.end_state is not None:
            result['EndState'] = self.end_state

        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.error_message is not None:
            result['ErrorMessage'] = self.error_message

        if self.external is not None:
            result['External'] = self.external

        if self.rate is not None:
            result['Rate'] = self.rate

        if self.request_duration is not None:
            result['RequestDuration'] = self.request_duration

        if self.smart_pressure_time is not None:
            result['SmartPressureTime'] = self.smart_pressure_time

        if self.source is not None:
            result['Source'] = self.source

        if self.sql_complete_reuse is not None:
            result['SqlCompleteReuse'] = self.sql_complete_reuse

        if self.src_instance_area is not None:
            result['SrcInstanceArea'] = self.src_instance_area

        if self.src_instance_uuid is not None:
            result['SrcInstanceUuid'] = self.src_instance_uuid

        if self.src_public_ip is not None:
            result['SrcPublicIp'] = self.src_public_ip

        if self.state is not None:
            result['State'] = self.state

        if self.status is not None:
            result['Status'] = self.status

        if self.table_schema is not None:
            result['TableSchema'] = self.table_schema

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_type is not None:
            result['TaskType'] = self.task_type

        if self.topic is not None:
            result['Topic'] = self.topic

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.version is not None:
            result['Version'] = self.version

        if self.work_dir is not None:
            result['WorkDir'] = self.work_dir

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ArchiveJobId') is not None:
            self.archive_job_id = m.get('ArchiveJobId')

        if m.get('ArchiveOssTableName') is not None:
            self.archive_oss_table_name = m.get('ArchiveOssTableName')

        if m.get('ArchiveState') is not None:
            self.archive_state = m.get('ArchiveState')

        if m.get('BackupId') is not None:
            self.backup_id = m.get('BackupId')

        if m.get('BackupType') is not None:
            self.backup_type = m.get('BackupType')

        if m.get('BenchStep') is not None:
            self.bench_step = m.get('BenchStep')

        if m.get('BenchStepStatus') is not None:
            self.bench_step_status = m.get('BenchStepStatus')

        if m.get('ClientGatewayId') is not None:
            self.client_gateway_id = m.get('ClientGatewayId')

        if m.get('ClientType') is not None:
            self.client_type = m.get('ClientType')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('DstInstanceUuid') is not None:
            self.dst_instance_uuid = m.get('DstInstanceUuid')

        if m.get('DstIp') is not None:
            self.dst_ip = m.get('DstIp')

        if m.get('DstPort') is not None:
            self.dst_port = m.get('DstPort')

        if m.get('DstType') is not None:
            self.dst_type = m.get('DstType')

        if m.get('DtsJobClass') is not None:
            self.dts_job_class = m.get('DtsJobClass')

        if m.get('DtsJobId') is not None:
            self.dts_job_id = m.get('DtsJobId')

        if m.get('DtsJobName') is not None:
            self.dts_job_name = m.get('DtsJobName')

        if m.get('DtsJobState') is not None:
            self.dts_job_state = m.get('DtsJobState')

        if m.get('DtsJobStatus') is not None:
            self.dts_job_status = m.get('DtsJobStatus')

        if m.get('EcsInstanceId') is not None:
            self.ecs_instance_id = m.get('EcsInstanceId')

        if m.get('EndState') is not None:
            self.end_state = m.get('EndState')

        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('ErrorMessage') is not None:
            self.error_message = m.get('ErrorMessage')

        if m.get('External') is not None:
            self.external = m.get('External')

        if m.get('Rate') is not None:
            self.rate = m.get('Rate')

        if m.get('RequestDuration') is not None:
            self.request_duration = m.get('RequestDuration')

        if m.get('SmartPressureTime') is not None:
            self.smart_pressure_time = m.get('SmartPressureTime')

        if m.get('Source') is not None:
            self.source = m.get('Source')

        if m.get('SqlCompleteReuse') is not None:
            self.sql_complete_reuse = m.get('SqlCompleteReuse')

        if m.get('SrcInstanceArea') is not None:
            self.src_instance_area = m.get('SrcInstanceArea')

        if m.get('SrcInstanceUuid') is not None:
            self.src_instance_uuid = m.get('SrcInstanceUuid')

        if m.get('SrcPublicIp') is not None:
            self.src_public_ip = m.get('SrcPublicIp')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TableSchema') is not None:
            self.table_schema = m.get('TableSchema')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskType') is not None:
            self.task_type = m.get('TaskType')

        if m.get('Topic') is not None:
            self.topic = m.get('Topic')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('Version') is not None:
            self.version = m.get('Version')

        if m.get('WorkDir') is not None:
            self.work_dir = m.get('WorkDir')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetQueryOptimizeTagRequest(DaraModel):
    def __init__(
        self,
        engine: str = None,
        instance_id: str = None,
        sql_id: str = None,
    ):
        # The database engine. Valid values:
        # 
        # *   **MySQL**: ApsaraDB RDS for MySQL
        # *   **PolarDBMySQL**: PolarDB for MySQL
        # *   **PostgreSQL**: ApsaraDB RDS for PostgreSQL
        # 
        # This parameter is required.
        self.engine = engine
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The SQL template ID. You can call the [GetQueryOptimizeDataStats](https://help.aliyun.com/document_detail/405261.html) operation to query the SQL template ID.
        # 
        # This parameter is required.
        self.sql_id = sql_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.engine is not None:
            result['Engine'] = self.engine

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Engine') is not None:
            self.engine = m.get('Engine')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetEndpointSwitchTaskResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetEndpointSwitchTaskResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
        synchro: str = None,
    ):
        self.code = code
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success
        self.synchro = synchro

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        if self.synchro is not None:
            result['Synchro'] = self.synchro

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetEndpointSwitchTaskResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('Synchro') is not None:
            self.synchro = m.get('Synchro')

        return self

class GetEndpointSwitchTaskResponseBodyData(DaraModel):
    def __init__(
        self,
        account_id: str = None,
        db_link_id: int = None,
        err_msg: str = None,
        ori_uuid: str = None,
        status: str = None,
        task_id: str = None,
        uuid: str = None,
    ):
        self.account_id = account_id
        self.db_link_id = db_link_id
        self.err_msg = err_msg
        self.ori_uuid = ori_uuid
        self.status = status
        self.task_id = task_id
        self.uuid = uuid

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_id is not None:
            result['AccountId'] = self.account_id

        if self.db_link_id is not None:
            result['DbLinkId'] = self.db_link_id

        if self.err_msg is not None:
            result['ErrMsg'] = self.err_msg

        if self.ori_uuid is not None:
            result['OriUuid'] = self.ori_uuid

        if self.status is not None:
            result['Status'] = self.status

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.uuid is not None:
            result['Uuid'] = self.uuid

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountId') is not None:
            self.account_id = m.get('AccountId')

        if m.get('DbLinkId') is not None:
            self.db_link_id = m.get('DbLinkId')

        if m.get('ErrMsg') is not None:
            self.err_msg = m.get('ErrMsg')

        if m.get('OriUuid') is not None:
            self.ori_uuid = m.get('OriUuid')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('Uuid') is not None:
            self.uuid = m.get('Uuid')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class ModifySqlLogConfigRequest(DaraModel):
    def __init__(
        self,
        enable: bool = None,
        enable_audit: bool = None,
        filters: List[main_models.ModifySqlLogConfigRequestFilters] = None,
        hot_retention: int = None,
        instance_id: str = None,
        request_enable: bool = None,
        retention: int = None,
    ):
        # Specifies whether to enable DAS Enterprise Edition. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  This parameter is required if you want to enable DAS Enterprise Edition. By default, the latest version of DAS Enterprise Edition that supports the database instance is enabled.
        self.enable = enable
        self.enable_audit = enable_audit
        # A reserved parameter.
        self.filters = filters
        # The number of days for which the SQL Explorer and Audit data is stored in hot storage. Valid values: 1 to 7.
        # 
        # >  This parameter is required if only DAS Enterprise Edition V3 can be enabled for the database instance.
        self.hot_retention = hot_retention
        # The ID of the database instance.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # Specifies whether to enable the SQL Explorer feature. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  This parameter is required if only DAS Enterprise Edition V3 can be enabled for the database instance.
        self.request_enable = request_enable
        # The total storage duration of the SQL Explorer and Audit data. Unit: day. Valid values:
        # 
        # *   7
        # *   30
        # *   180
        # *   365
        # 
        # >  If you want to enable DAS Enterprise Edition V3, the value of this parameter must be greater than or equal to 30.
        self.retention = retention

    def validate(self):
        if self.filters:
            for v1 in self.filters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['Enable'] = self.enable

        if self.enable_audit is not None:
            result['EnableAudit'] = self.enable_audit

        result['Filters'] = []
        if self.filters is not None:
            for k1 in self.filters:
                result['Filters'].append(k1.to_map() if k1 else None)

        if self.hot_retention is not None:
            result['HotRetention'] = self.hot_retention

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.request_enable is not None:
            result['RequestEnable'] = self.request_enable

        if self.retention is not None:
            result['Retention'] = self.retention

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Enable') is not None:
            self.enable = m.get('Enable')

        if m.get('EnableAudit') is not None:
            self.enable_audit = m.get('EnableAudit')

        self.filters = []
        if m.get('Filters') is not None:
            for k1 in m.get('Filters'):
                temp_model = main_models.ModifySqlLogConfigRequestFilters()
                self.filters.append(temp_model.from_map(k1))

        if m.get('HotRetention') is not None:
            self.hot_retention = m.get('HotRetention')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('RequestEnable') is not None:
            self.request_enable = m.get('RequestEnable')

        if m.get('Retention') is not None:
            self.retention = m.get('Retention')

        return self

class ModifySqlLogConfigRequestFilters(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # A reserved parameter.
        self.key = key
        # A reserved parameter.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetRequestDiagnosisResultResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetRequestDiagnosisResultResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, Successful is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetRequestDiagnosisResultResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetRequestDiagnosisResultResponseBodyData(DaraModel):
    def __init__(
        self,
        account_id: str = None,
        db_schema: str = None,
        engine: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        message_id: str = None,
        param: str = None,
        result: str = None,
        sql_id: str = None,
        state: int = None,
        uuid: str = None,
    ):
        # The user ID.
        self.account_id = account_id
        # The name of the database.
        self.db_schema = db_schema
        # The database engine. Valid values:
        # 
        # *   **MySQL**
        # *   **PostgreSQL**
        # *   **SQLServer**
        # *   **PolarDBMySQL**
        # *   **PolarDBOracle**
        # *   **MongoDB**
        self.engine = engine
        # The time when the SQL diagnostics task was created. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.gmt_create = gmt_create
        # The time when the SQL diagnostics task was modified. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.gmt_modified = gmt_modified
        # The unique ID of the diagnostics task.
        self.message_id = message_id
        # The additional information.
        self.param = param
        # The result of the SQL diagnostics task. The result includes the following information:
        # 
        # *   **endTime**: the end time of the SQL diagnostics task.
        # 
        # *   **errorCode**: the error code.
        # 
        #     *   **0001**: The SQL diagnostics task is complete.
        #     *   **0003**: The SQL diagnostics task failed.
        # 
        # *   **errorMessage**: the error message.
        # 
        # *   **estimateCost**: the estimated cost.
        # 
        #     *   **cpu**: the estimated CPU utilization of the index.
        #     *   **io**: the estimated I/O usage of the index.
        #     *   **rows**: the estimated values of the rows returned for the index.
        # 
        # *   **improvement**: the performance improvement ratio.
        # 
        # *   **indexAdvices**: the index recommendations, which include the following information:
        # 
        #     *   **columns**: the index columns.
        #     *   **ddlAddIndex**: the DDL statement for the index.
        #     *   **indexName**: the name of the index.
        #     *   **schemaName**: the name of the database.
        #     *   **tableName**: the name of the table.
        #     *   **unique**: indicates whether the index is unique.
        # 
        # *   **ip**: the IP address of the instance.
        # 
        # *   **messageId**: the ID of the diagnostics task.
        # 
        # *   **port**: the port used to connect to the instance.
        # 
        # *   **sqlTag**: the SQL tag.
        # 
        # *   **startTime**: the start time of the SQL diagnostics task.
        # 
        # *   **success**: indicates whether the request was successful.
        # 
        # *   **support**: indicates whether the SQL statement can be diagnosed. Valid values:
        # 
        #     *   **true**
        #     *   **false**
        # 
        # *   **tuningAdvices** : the SQL rewrite suggestions.
        self.result = result
        # The SQL template ID.
        self.sql_id = sql_id
        # The state of the diagnostics task. Valid values:
        # 
        # *   **0**: The diagnostics task is in progress.
        # *   **1**: A diagnostics error occurred.
        # *   **2**: The diagnostics task is complete.
        # *   **3**: An SQL error occurred.
        # *   **4**: An engine error occurred.
        self.state = state
        # The unique ID of the diagnostics instance.
        self.uuid = uuid

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_id is not None:
            result['accountId'] = self.account_id

        if self.db_schema is not None:
            result['dbSchema'] = self.db_schema

        if self.engine is not None:
            result['engine'] = self.engine

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.message_id is not None:
            result['messageId'] = self.message_id

        if self.param is not None:
            result['param'] = self.param

        if self.result is not None:
            result['result'] = self.result

        if self.sql_id is not None:
            result['sqlId'] = self.sql_id

        if self.state is not None:
            result['state'] = self.state

        if self.uuid is not None:
            result['uuid'] = self.uuid

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('accountId') is not None:
            self.account_id = m.get('accountId')

        if m.get('dbSchema') is not None:
            self.db_schema = m.get('dbSchema')

        if m.get('engine') is not None:
            self.engine = m.get('engine')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('messageId') is not None:
            self.message_id = m.get('messageId')

        if m.get('param') is not None:
            self.param = m.get('param')

        if m.get('result') is not None:
            self.result = m.get('result')

        if m.get('sqlId') is not None:
            self.sql_id = m.get('sqlId')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('uuid') is not None:
            self.uuid = m.get('uuid')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetStorageAnalysisResultResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetStorageAnalysisResultResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request is successful, **Successful** is returned. Otherwise, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request is successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetStorageAnalysisResultResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetStorageAnalysisResultResponseBodyData(DaraModel):
    def __init__(
        self,
        analyzed_db_count: int = None,
        storage_analysis_result: main_models.GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult = None,
        task_finish: bool = None,
        task_id: str = None,
        task_progress: int = None,
        task_state: str = None,
        task_success: bool = None,
        total_db_count: int = None,
    ):
        # The number of databases that have been analyzed.
        self.analyzed_db_count = analyzed_db_count
        # The details of storage analysis.
        self.storage_analysis_result = storage_analysis_result
        # Indicates whether the task is complete.
        self.task_finish = task_finish
        # The task ID.
        self.task_id = task_id
        # The task progress.
        # 
        # >  Valid values are integers that range from 0 to 100.
        self.task_progress = task_progress
        # The status of the storage analysis task. Valid values:
        # 
        # *   **INIT**: The task is being initialized.
        # *   **PENDING**: The task is being queued for execution.
        # *   **RECEIVED**: The task is received for execution.
        # *   **RUNNING**: The task is being executed.
        # *   **RETRY**: The task is being retried.
        # *   **SUCCESS**: The task succeeds.
        # *   **FAILURE**: The task fails.
        self.task_state = task_state
        # Indicates whether the task is successful.
        self.task_success = task_success
        # The number of databases that need to be analyzed in the storage analysis task.
        self.total_db_count = total_db_count

    def validate(self):
        if self.storage_analysis_result:
            self.storage_analysis_result.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.analyzed_db_count is not None:
            result['AnalyzedDbCount'] = self.analyzed_db_count

        if self.storage_analysis_result is not None:
            result['StorageAnalysisResult'] = self.storage_analysis_result.to_map()

        if self.task_finish is not None:
            result['TaskFinish'] = self.task_finish

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_progress is not None:
            result['TaskProgress'] = self.task_progress

        if self.task_state is not None:
            result['TaskState'] = self.task_state

        if self.task_success is not None:
            result['TaskSuccess'] = self.task_success

        if self.total_db_count is not None:
            result['TotalDbCount'] = self.total_db_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AnalyzedDbCount') is not None:
            self.analyzed_db_count = m.get('AnalyzedDbCount')

        if m.get('StorageAnalysisResult') is not None:
            temp_model = main_models.GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult()
            self.storage_analysis_result = temp_model.from_map(m.get('StorageAnalysisResult'))

        if m.get('TaskFinish') is not None:
            self.task_finish = m.get('TaskFinish')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskProgress') is not None:
            self.task_progress = m.get('TaskProgress')

        if m.get('TaskState') is not None:
            self.task_state = m.get('TaskState')

        if m.get('TaskSuccess') is not None:
            self.task_success = m.get('TaskSuccess')

        if m.get('TotalDbCount') is not None:
            self.total_db_count = m.get('TotalDbCount')

        return self

class GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult(DaraModel):
    def __init__(
        self,
        analysis_error_type: str = None,
        analysis_success: bool = None,
        daily_increment: int = None,
        estimate_available_days: int = None,
        need_optimize_item_list: List[main_models.GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList] = None,
        table_stats: List[main_models.GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats] = None,
        total_free_storage_size: int = None,
        total_storage_size: int = None,
        total_used_storage_size: int = None,
    ):
        # The reason why the analysis on the database and table fails.
        # 
        # *   **DB_OR_TABLE_NOT_EXIST**: The specified database or table does not exist.
        # *   **DB_NOT_EXIST**: The specified database does not exist.
        self.analysis_error_type = analysis_error_type
        # Indicates whether the analysis on the database and table is successful.
        self.analysis_success = analysis_success
        # The estimated average daily growth of the used storage space in the previous seven days. Unit: bytes.
        self.daily_increment = daily_increment
        # The estimated number of days for which the remaining storage space is available.
        self.estimate_available_days = estimate_available_days
        # The items to be optimized, which are generated based on DAS default rules. You can ignore these items based on your business requirements, and create custom rules to generate items to be optimized based on other basic data that is returned.
        self.need_optimize_item_list = need_optimize_item_list
        # The information about the table.
        self.table_stats = table_stats
        # The size of remaining storage.
        # 
        # >  Unit: bytes.
        self.total_free_storage_size = total_free_storage_size
        # The total size of instance storage.
        # 
        # >  Unit: bytes.
        self.total_storage_size = total_storage_size
        # The size of used storage.
        # 
        # >  Unit: bytes.
        self.total_used_storage_size = total_used_storage_size

    def validate(self):
        if self.need_optimize_item_list:
            for v1 in self.need_optimize_item_list:
                 if v1:
                    v1.validate()
        if self.table_stats:
            for v1 in self.table_stats:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.analysis_error_type is not None:
            result['AnalysisErrorType'] = self.analysis_error_type

        if self.analysis_success is not None:
            result['AnalysisSuccess'] = self.analysis_success

        if self.daily_increment is not None:
            result['DailyIncrement'] = self.daily_increment

        if self.estimate_available_days is not None:
            result['EstimateAvailableDays'] = self.estimate_available_days

        result['NeedOptimizeItemList'] = []
        if self.need_optimize_item_list is not None:
            for k1 in self.need_optimize_item_list:
                result['NeedOptimizeItemList'].append(k1.to_map() if k1 else None)

        result['TableStats'] = []
        if self.table_stats is not None:
            for k1 in self.table_stats:
                result['TableStats'].append(k1.to_map() if k1 else None)

        if self.total_free_storage_size is not None:
            result['TotalFreeStorageSize'] = self.total_free_storage_size

        if self.total_storage_size is not None:
            result['TotalStorageSize'] = self.total_storage_size

        if self.total_used_storage_size is not None:
            result['TotalUsedStorageSize'] = self.total_used_storage_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AnalysisErrorType') is not None:
            self.analysis_error_type = m.get('AnalysisErrorType')

        if m.get('AnalysisSuccess') is not None:
            self.analysis_success = m.get('AnalysisSuccess')

        if m.get('DailyIncrement') is not None:
            self.daily_increment = m.get('DailyIncrement')

        if m.get('EstimateAvailableDays') is not None:
            self.estimate_available_days = m.get('EstimateAvailableDays')

        self.need_optimize_item_list = []
        if m.get('NeedOptimizeItemList') is not None:
            for k1 in m.get('NeedOptimizeItemList'):
                temp_model = main_models.GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList()
                self.need_optimize_item_list.append(temp_model.from_map(k1))

        self.table_stats = []
        if m.get('TableStats') is not None:
            for k1 in m.get('TableStats'):
                temp_model = main_models.GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats()
                self.table_stats.append(temp_model.from_map(k1))

        if m.get('TotalFreeStorageSize') is not None:
            self.total_free_storage_size = m.get('TotalFreeStorageSize')

        if m.get('TotalStorageSize') is not None:
            self.total_storage_size = m.get('TotalStorageSize')

        if m.get('TotalUsedStorageSize') is not None:
            self.total_used_storage_size = m.get('TotalUsedStorageSize')

        return self

class GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats(DaraModel):
    def __init__(
        self,
        avg_row_length: int = None,
        data_free: int = None,
        data_size: int = None,
        db_name: str = None,
        engine: str = None,
        fragment_size: int = None,
        index_size: int = None,
        phy_total_size: int = None,
        physical_file_size: int = None,
        table_name: str = None,
        table_rows: int = None,
        table_type: str = None,
        total_size: int = None,
    ):
        # The average length of rows. Unit: bytes.
        self.avg_row_length = avg_row_length
        # The size of space fragments. Unit: bytes.
        # 
        # >  This parameter is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters. The fragmentation rate of a table is generally calculated based on the following formula: `Fragmentation rate = DataFree/(DataSize + IndexSize + DataFree)`. In this topic, `Fragmentation rate = DataFree/PhyTotalSize`.
        self.data_free = data_free
        # *   For ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters, this parameter indicates the amount of space occupied by data. Unit: bytes.
        # *   For ApsaraDB for MongoDB instances, this parameter indicates the size of uncompressed data, that is, the amount of data. Unit: bytes.
        self.data_size = data_size
        # The name of the database.
        self.db_name = db_name
        # The type of the storage engine used by the table.
        # 
        # >  This parameter is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        self.engine = engine
        # The size of space that can be reclaimed. Unit: bytes.
        # 
        # >  This parameter is applicable only to ApsaraDB for MongoDB instances. `Fragmentation rate = FragmentSize/PhyTotalSize`.
        self.fragment_size = fragment_size
        # The storage space occupied by indexes. Unit: bytes.
        self.index_size = index_size
        # The storage space of the table. Unit: bytes.
        # 
        # >  For ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters, the value of the parameter is the sum of **DataSize**, **IndexSize**, and **DataFree**. For ApsaraDB for MongoDB instances, the value of this parameter is the sum of **DataSize** and **IndexSize**.
        self.phy_total_size = phy_total_size
        # The physical file size of the table. Unit: bytes.
        # 
        # >  This parameter is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters. Data of specific database instances cannot be obtained due to deployment mode.
        self.physical_file_size = physical_file_size
        # The name of the table.
        self.table_name = table_name
        # The number of rows in the table.
        self.table_rows = table_rows
        # The type of the table.
        # 
        # >  This parameter is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        self.table_type = table_type
        # *   For ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters, this parameter indicates the amount of space occupied by table data and indexes. Unit: bytes. The value is the sum of **DataSize** and **IndexSize**.
        # *   For ApsaraDB for MongoDB instances, this parameter indicates the actual size of space allocated by Block Manager. Unit: Bytes. The compression ratio of an ApsaraDB for MongoDB instance is calculated based on the following formula: `Compression ratio = TotalSize/DataSize`.
        self.total_size = total_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_row_length is not None:
            result['AvgRowLength'] = self.avg_row_length

        if self.data_free is not None:
            result['DataFree'] = self.data_free

        if self.data_size is not None:
            result['DataSize'] = self.data_size

        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.engine is not None:
            result['Engine'] = self.engine

        if self.fragment_size is not None:
            result['FragmentSize'] = self.fragment_size

        if self.index_size is not None:
            result['IndexSize'] = self.index_size

        if self.phy_total_size is not None:
            result['PhyTotalSize'] = self.phy_total_size

        if self.physical_file_size is not None:
            result['PhysicalFileSize'] = self.physical_file_size

        if self.table_name is not None:
            result['TableName'] = self.table_name

        if self.table_rows is not None:
            result['TableRows'] = self.table_rows

        if self.table_type is not None:
            result['TableType'] = self.table_type

        if self.total_size is not None:
            result['TotalSize'] = self.total_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgRowLength') is not None:
            self.avg_row_length = m.get('AvgRowLength')

        if m.get('DataFree') is not None:
            self.data_free = m.get('DataFree')

        if m.get('DataSize') is not None:
            self.data_size = m.get('DataSize')

        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('Engine') is not None:
            self.engine = m.get('Engine')

        if m.get('FragmentSize') is not None:
            self.fragment_size = m.get('FragmentSize')

        if m.get('IndexSize') is not None:
            self.index_size = m.get('IndexSize')

        if m.get('PhyTotalSize') is not None:
            self.phy_total_size = m.get('PhyTotalSize')

        if m.get('PhysicalFileSize') is not None:
            self.physical_file_size = m.get('PhysicalFileSize')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        if m.get('TableRows') is not None:
            self.table_rows = m.get('TableRows')

        if m.get('TableType') is not None:
            self.table_type = m.get('TableType')

        if m.get('TotalSize') is not None:
            self.total_size = m.get('TotalSize')

        return self

class GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList(DaraModel):
    def __init__(
        self,
        associated_data: str = None,
        db_name: str = None,
        optimize_advice: str = None,
        optimize_item_name: str = None,
        table_name: str = None,
    ):
        # The data associated with the items to be optimized, which is in the JSON format.
        self.associated_data = associated_data
        # The name of the database.
        self.db_name = db_name
        # The optimization suggestion. Valid values:
        # 
        # *   **NEED_ANALYZE_TABLE**: You can execute the `ANALYZE TABLE` statement on the table during off-peak hours. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # *   **NEED_OPTIMIZE_TABLE**: You can reclaim fragments during off-peak hours.
        # *   **CHANGE_TABLE_ENGINE_IF_NECESSARY**: Change the storage engine type of a table after risk assessment. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # *   **AUTO_INCREMENT_ID_BE_TO_RUN_OUT**: Pay attention to the usage of auto-increment IDs. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # *   **DUPLICATE_INDEX**: Optimize indexes of tables. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # *   **TABLE_SIZE**: Pay attention to the table size. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # *   **TABLE_ROWS_AND_AVG_ROW_LENGTH**: Pay attention to the number of rows in a table and the average row length. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # *   **STORAGE_USED_PERCENT**: Pay attention to the space usage to prevent the instance from being locked if the instance is full.
        self.optimize_advice = optimize_advice
        # The item to be optimized. Valid values:
        # 
        # *   **NEED_ANALYZE_TABLE**: tables whose storage statistics obtained from `information_schema.tables` are 50 GB larger or smaller than the physical file sizes. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # 
        # *   **NEED_OPTIMIZE_TABLE**: tables whose space fragments are larger than 6 GB and whose fragmentation rates are greater than 30%. The fragmentation rate of a table is generally calculated based on the following formulas:
        # 
        #     *   ApsaraDB RDS for MySQL and PolarDB for MySQL: `Fragmentation rate = DataFree/(DataSize + IndexSize + DataFree)`. In this topic, PhyTotalSize = DataSize + IndexSize + DataFree. Thus, the fragmentation rate can be calculated based on the following formula: `Fragmentation rate = DataFree/PhyTotalSize`.
        #     *   ApsaraDB for MongoDB: `Fragmentation rate = FragmentSize/PhyTotalSize`.
        # 
        # *   **TABLE_ENGINE**: tables whose storage engines are not InnoDB or XEngine. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # 
        # *   **AUTO_INCREMENT_ID_BE_TO_RUN_OUT**: tables whose usages of auto-increment IDs exceed 80%. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # 
        # *   **DUPLICATE_INDEX**: tables whose indexes are redundant or duplicate. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # 
        # *   **TABLE_SIZE**: single tables whose sizes are larger than 50 GB. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # 
        # *   **TABLE_ROWS_AND_AVG_ROW_LENGTH**: single tables that contain more than 5 million rows and whose average row lengths exceed 10 KB. This is applicable only to ApsaraDB RDS for MySQL instances and PolarDB for MySQL clusters.
        # 
        # *   **TOTAL_DATA_FREE**: instances whose reclaimable space is larger than 60 GB and whose total fragmentation rate is larger than 5%.
        # 
        # *   **STORAGE_USED_PERCENT**: instances whose space usage is larger than 90%.
        self.optimize_item_name = optimize_item_name
        # The name of the table.
        self.table_name = table_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.associated_data is not None:
            result['AssociatedData'] = self.associated_data

        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.optimize_advice is not None:
            result['OptimizeAdvice'] = self.optimize_advice

        if self.optimize_item_name is not None:
            result['OptimizeItemName'] = self.optimize_item_name

        if self.table_name is not None:
            result['TableName'] = self.table_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AssociatedData') is not None:
            self.associated_data = m.get('AssociatedData')

        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('OptimizeAdvice') is not None:
            self.optimize_advice = m.get('OptimizeAdvice')

        if m.get('OptimizeItemName') is not None:
            self.optimize_item_name = m.get('OptimizeItemName')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetRedisAllSessionResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetRedisAllSessionResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The session data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetRedisAllSessionResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetRedisAllSessionResponseBodyData(DaraModel):
    def __init__(
        self,
        sessions: List[main_models.GetRedisAllSessionResponseBodyDataSessions] = None,
        source_stats: List[main_models.GetRedisAllSessionResponseBodyDataSourceStats] = None,
        timestamp: int = None,
        total: int = None,
    ):
        # The information about the sessions.
        self.sessions = sessions
        # The statistics on the access source.
        self.source_stats = source_stats
        # The time when the instance sessions were returned. The value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        # The total number of sessions.
        self.total = total

    def validate(self):
        if self.sessions:
            for v1 in self.sessions:
                 if v1:
                    v1.validate()
        if self.source_stats:
            for v1 in self.source_stats:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Sessions'] = []
        if self.sessions is not None:
            for k1 in self.sessions:
                result['Sessions'].append(k1.to_map() if k1 else None)

        result['SourceStats'] = []
        if self.source_stats is not None:
            for k1 in self.source_stats:
                result['SourceStats'].append(k1.to_map() if k1 else None)

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.sessions = []
        if m.get('Sessions') is not None:
            for k1 in m.get('Sessions'):
                temp_model = main_models.GetRedisAllSessionResponseBodyDataSessions()
                self.sessions.append(temp_model.from_map(k1))

        self.source_stats = []
        if m.get('SourceStats') is not None:
            for k1 in m.get('SourceStats'):
                temp_model = main_models.GetRedisAllSessionResponseBodyDataSourceStats()
                self.source_stats.append(temp_model.from_map(k1))

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetRedisAllSessionResponseBodyDataSourceStats(DaraModel):
    def __init__(
        self,
        count: str = None,
        ids: List[int] = None,
        key: str = None,
    ):
        # The total number of sessions from the access source.
        self.count = count
        # The client IDs.
        self.ids = ids
        # The access source.
        self.key = key

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['Count'] = self.count

        if self.ids is not None:
            result['Ids'] = self.ids

        if self.key is not None:
            result['Key'] = self.key

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Ids') is not None:
            self.ids = m.get('Ids')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        return self

class GetRedisAllSessionResponseBodyDataSessions(DaraModel):
    def __init__(
        self,
        addr: str = None,
        age: str = None,
        client: str = None,
        client_desc: str = None,
        cmd: str = None,
        db: int = None,
        events: str = None,
        fd: int = None,
        flags: str = None,
        id: int = None,
        idle: int = None,
        multi: int = None,
        name: str = None,
        node_id: str = None,
        obl: int = None,
        oll: int = None,
        omem: int = None,
        psub: int = None,
        qbuf: int = None,
        qbuf_free: int = None,
        sub: int = None,
    ):
        # The IP address and port number of the client.
        self.addr = addr
        # The connection duration of the session. Unit: seconds.
        self.age = age
        # The IP address of the client.
        self.client = client
        # The alias of the client.
        self.client_desc = client_desc
        # The command that was last run.
        self.cmd = cmd
        # The ID of the database that the client is using.
        self.db = db
        # The file descriptor event. Valid values:
        # 
        # *   **r**: Client sockets are readable in the event loop.
        # *   **w**: Client sockets are writable in the event loop.
        self.events = events
        # The file descriptor that is used by sockets.
        self.fd = fd
        # The client flag. Valid values:
        # 
        # *   **A**: The connection needs to be closed at the earliest opportunity.
        # *   **b**: The client is waiting for blocked events.
        # *   **c**: The connection is closed after all replies are written.
        # *   **d**: The monitored keys have been modified, and the `EXEC` command is about to fail.
        # *   **i**: The client is waiting for VM I/O operations. This value is no longer used.
        # *   **M**: The client is the primary node.
        # *   **N**: No special flags are configured.
        # *   **O**: The client is in monitor mode.
        # *   **r**: The client is a cluster node in read-only mode.
        # *   **S**: The client is a replica node in normal mode.
        # *   **u**: The client is not blocked.
        # *   **U**: The client is connected by using UNIX domain sockets.
        # *   **x**: The client is executing a transaction.
        self.flags = flags
        # The client ID.
        self.id = id
        # The duration during which the session is in the idle state. Unit: seconds.
        self.idle = idle
        # The number of commands in `MULTI` or `EXEC`.
        self.multi = multi
        # The name of the client.
        self.name = name
        # The node ID.
        self.node_id = node_id
        # The size of the fixed output buffer. Unit: bytes.
        self.obl = obl
        # The number of objects contained in the output list.
        self.oll = oll
        # The size of the output buffer. Unit: bytes.
        self.omem = omem
        # The number of subscriptions that match the pattern.
        self.psub = psub
        # The size of the input buffer. Unit: bytes.
        self.qbuf = qbuf
        # The remaining size of the input buffer. Unit: bytes.
        self.qbuf_free = qbuf_free
        # The number of subscribed channels.
        self.sub = sub

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.addr is not None:
            result['Addr'] = self.addr

        if self.age is not None:
            result['Age'] = self.age

        if self.client is not None:
            result['Client'] = self.client

        if self.client_desc is not None:
            result['ClientDesc'] = self.client_desc

        if self.cmd is not None:
            result['Cmd'] = self.cmd

        if self.db is not None:
            result['Db'] = self.db

        if self.events is not None:
            result['Events'] = self.events

        if self.fd is not None:
            result['Fd'] = self.fd

        if self.flags is not None:
            result['Flags'] = self.flags

        if self.id is not None:
            result['Id'] = self.id

        if self.idle is not None:
            result['Idle'] = self.idle

        if self.multi is not None:
            result['Multi'] = self.multi

        if self.name is not None:
            result['Name'] = self.name

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.obl is not None:
            result['Obl'] = self.obl

        if self.oll is not None:
            result['Oll'] = self.oll

        if self.omem is not None:
            result['Omem'] = self.omem

        if self.psub is not None:
            result['Psub'] = self.psub

        if self.qbuf is not None:
            result['Qbuf'] = self.qbuf

        if self.qbuf_free is not None:
            result['QbufFree'] = self.qbuf_free

        if self.sub is not None:
            result['Sub'] = self.sub

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Addr') is not None:
            self.addr = m.get('Addr')

        if m.get('Age') is not None:
            self.age = m.get('Age')

        if m.get('Client') is not None:
            self.client = m.get('Client')

        if m.get('ClientDesc') is not None:
            self.client_desc = m.get('ClientDesc')

        if m.get('Cmd') is not None:
            self.cmd = m.get('Cmd')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Events') is not None:
            self.events = m.get('Events')

        if m.get('Fd') is not None:
            self.fd = m.get('Fd')

        if m.get('Flags') is not None:
            self.flags = m.get('Flags')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('Idle') is not None:
            self.idle = m.get('Idle')

        if m.get('Multi') is not None:
            self.multi = m.get('Multi')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Obl') is not None:
            self.obl = m.get('Obl')

        if m.get('Oll') is not None:
            self.oll = m.get('Oll')

        if m.get('Omem') is not None:
            self.omem = m.get('Omem')

        if m.get('Psub') is not None:
            self.psub = m.get('Psub')

        if m.get('Qbuf') is not None:
            self.qbuf = m.get('Qbuf')

        if m.get('QbufFree') is not None:
            self.qbuf_free = m.get('QbufFree')

        if m.get('Sub') is not None:
            self.sub = m.get('Sub')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class RunCloudBenchTaskResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.RunCloudBenchTaskResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.RunCloudBenchTaskResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class RunCloudBenchTaskResponseBodyData(DaraModel):
    def __init__(
        self,
        pre_check_item: List[main_models.RunCloudBenchTaskResponseBodyDataPreCheckItem] = None,
    ):
        self.pre_check_item = pre_check_item

    def validate(self):
        if self.pre_check_item:
            for v1 in self.pre_check_item:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['PreCheckItem'] = []
        if self.pre_check_item is not None:
            for k1 in self.pre_check_item:
                result['PreCheckItem'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.pre_check_item = []
        if m.get('PreCheckItem') is not None:
            for k1 in m.get('PreCheckItem'):
                temp_model = main_models.RunCloudBenchTaskResponseBodyDataPreCheckItem()
                self.pre_check_item.append(temp_model.from_map(k1))

        return self

class RunCloudBenchTaskResponseBodyDataPreCheckItem(DaraModel):
    def __init__(
        self,
        code: int = None,
        details: str = None,
        message: str = None,
        name: str = None,
        order: int = None,
        status: str = None,
    ):
        self.code = code
        self.details = details
        self.message = message
        self.name = name
        self.order = order
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.details is not None:
            result['Details'] = self.details

        if self.message is not None:
            result['Message'] = self.message

        if self.name is not None:
            result['Name'] = self.name

        if self.order is not None:
            result['Order'] = self.order

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Details') is not None:
            self.details = m.get('Details')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Order') is not None:
            self.order = m.get('Order')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetPfsSqlSummariesRequest(DaraModel):
    def __init__(
        self,
        asc: bool = None,
        end_time: int = None,
        instance_id: str = None,
        keywords: str = None,
        node_id: str = None,
        order_by: str = None,
        page_no: int = None,
        page_size: int = None,
        sql_id: str = None,
        start_time: int = None,
    ):
        # Specifies whether to sort the returned entries in ascending order. Default value: **false**. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.asc = asc
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The end time must be later than the start time. You can view the data of up to seven days within the last month.
        self.end_time = end_time
        # The instance ID.
        self.instance_id = instance_id
        # The keywords of the SQL template. Separate multiple keywords with spaces.
        self.keywords = keywords
        # The node ID.
        # 
        # >  This parameter is required if the database instance is an ApsaraDB RDS for MySQL Cluster Edition instance or a PolarDB for MySQL cluster.
        self.node_id = node_id
        # The field by which to sort the returned entries. Default value: **count**.
        # 
        # *   **count**: the number of executions.
        # *   **avgRt**: the average execution duration.
        # *   **rtRate**: the execution duration percentage.
        # *   **rowsExamined**: the total number of scanned rows.
        # *   **avgRowsExamined**: the average number of scanned rows.
        # *   **avgRowsReturned**: the average number of returned rows.
        self.order_by = order_by
        # The page number. Pages start from page 1. Default value: 1.
        self.page_no = page_no
        # The number of entries per page. Default value: 10. Valid values: 1 to 100.
        self.page_size = page_size
        # The SQL ID.
        # 
        # >  If this parameter is specified, the full request statistics of the specified SQL query are collected. If this parameter is left empty, the full request statistics of the entire database instance are collected.
        self.sql_id = sql_id
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.asc is not None:
            result['Asc'] = self.asc

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.keywords is not None:
            result['Keywords'] = self.keywords

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.order_by is not None:
            result['OrderBy'] = self.order_by

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Asc') is not None:
            self.asc = m.get('Asc')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Keywords') is not None:
            self.keywords = m.get('Keywords')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OrderBy') is not None:
            self.order_by = m.get('OrderBy')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Any, List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetPfsSqlSummariesResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetPfsSqlSummariesResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetPfsSqlSummariesResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetPfsSqlSummariesResponseBodyData(DaraModel):
    def __init__(
        self,
        extra: Any = None,
        list: List[main_models.GetPfsSqlSummariesResponseBodyDataList] = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The reserved parameter.
        self.extra = extra
        # The details of the data returned.
        self.list = list
        # The page number.
        self.page_no = page_no
        # The number of entries per page.
        self.page_size = page_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.extra is not None:
            result['Extra'] = self.extra

        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Extra') is not None:
            self.extra = m.get('Extra')

        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.GetPfsSqlSummariesResponseBodyDataList()
                self.list.append(temp_model.from_map(k1))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetPfsSqlSummariesResponseBodyDataList(DaraModel):
    def __init__(
        self,
        avg_latency: float = None,
        count: int = None,
        count_rate: float = None,
        cpu_rate: float = None,
        cpu_time: float = None,
        data_read_time: float = None,
        data_reads: int = None,
        data_write_time: float = None,
        data_writes: int = None,
        db: str = None,
        elapsed_time: float = None,
        err_count: int = None,
        first_time: int = None,
        full_scan: bool = None,
        id: int = None,
        instance_id: str = None,
        last_time: int = None,
        lock_latency_avg: float = None,
        logic_id: int = None,
        logic_reads: int = None,
        max_latency: float = None,
        mutex_spins: int = None,
        mutex_waits: int = None,
        node_id: str = None,
        physical_async_reads: int = None,
        physical_reads: int = None,
        psql: str = None,
        redo_writes: int = None,
        rows_affected: int = None,
        rows_affected_avg: float = None,
        rows_examined: int = None,
        rows_examined_avg: float = None,
        rows_send_avg: float = None,
        rows_sent: int = None,
        rows_sent_avg: float = None,
        rows_sorted: int = None,
        rt_rate: float = None,
        rwlock_os_waits: int = None,
        rwlock_spin_rounds: int = None,
        rwlock_spin_waits: int = None,
        select_full_join_avg: float = None,
        select_full_range_join_avg: float = None,
        select_range_avg: float = None,
        select_scan_avg: float = None,
        semisync_delay_time: float = None,
        server_lock_time: float = None,
        sort_merge_passes: int = None,
        sort_range_avg: float = None,
        sort_rows_avg: float = None,
        sort_scan_avg: float = None,
        sql_id: str = None,
        sql_type: str = None,
        tables: List[str] = None,
        timer_wait_avg: float = None,
        timestamp: int = None,
        tmp_disk_tables: int = None,
        tmp_disk_tables_avg: float = None,
        tmp_tables: int = None,
        tmp_tables_avg: float = None,
        total_latency: float = None,
        transaction_lock_time: float = None,
        user_id: str = None,
        warn_count: int = None,
    ):
        # The average execution latency. Unit: millisecond.
        self.avg_latency = avg_latency
        # The total number of executions.
        self.count = count
        # The percentage of the number of executions.
        self.count_rate = count_rate
        # The ratio of the CPU execution duration to the total execution duration of the SQL statement.
        self.cpu_rate = cpu_rate
        # The CPU execution duration. Unit: millisecond.
        self.cpu_time = cpu_time
        # The data read duration. Unit: millisecond.
        self.data_read_time = data_read_time
        # The number of nodes from which data can be read.
        self.data_reads = data_reads
        # The data write duration. Unit: millisecond.
        self.data_write_time = data_write_time
        # The number of nodes to which data can be written.
        self.data_writes = data_writes
        # The name of the database.
        self.db = db
        # The execution duration. Unit: millisecond.
        self.elapsed_time = elapsed_time
        # The number of errors.
        self.err_count = err_count
        # The time when the SQL statement was executed for the first time. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.first_time = first_time
        # Indicates whether full table scan was enabled. Valid values:
        # 
        # * **true**
        # * **false**
        self.full_scan = full_scan
        # The primary key ID.
        self.id = id
        # The instance ID.
        self.instance_id = instance_id
        # The time when the SQL statement was last modified. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.last_time = last_time
        # The average lock wait latency. Unit: millisecond.
        self.lock_latency_avg = lock_latency_avg
        # The logical database ID.
        self.logic_id = logic_id
        # The number of logical nodes.
        self.logic_reads = logic_reads
        # The maximum execution latency. Unit: millisecond.
        self.max_latency = max_latency
        # The number of mutex spins.
        self.mutex_spins = mutex_spins
        # The number of mutex waits.
        self.mutex_waits = mutex_waits
        # The node ID.
        # 
        # >  This parameter is returned only if the database instance is an ApsaraDB RDS for MySQL Cluster Edition instance or a PolarDB for MySQL cluster.
        self.node_id = node_id
        # The number of physical asynchronous nodes.
        self.physical_async_reads = physical_async_reads
        # The number of physical nodes.
        self.physical_reads = physical_reads
        # The SQL template.
        self.psql = psql
        # The number of redo nodes.
        self.redo_writes = redo_writes
        # The number of rows that are affected by the SQL statement.
        self.rows_affected = rows_affected
        # The average number of rows affected by the SQL statement.
        self.rows_affected_avg = rows_affected_avg
        # The total number of scanned rows.
        self.rows_examined = rows_examined
        # The average number of scanned rows.
        self.rows_examined_avg = rows_examined_avg
        # The average number of returned rows.
        self.rows_send_avg = rows_send_avg
        # The number of rows returned by the SQL statement.
        self.rows_sent = rows_sent
        # The average number of rows returned for the SQL statement.
        self.rows_sent_avg = rows_sent_avg
        # The number of sorted rows.
        self.rows_sorted = rows_sorted
        # The execution duration percentage.
        self.rt_rate = rt_rate
        # Indicates whether read/write splitting was enabled. Valid values:
        # 
        # * **0:** Read/write splitting was disabled.
        # * **1:** Read/write splitting was enabled.
        self.rwlock_os_waits = rwlock_os_waits
        # The read/write splitting parameters.
        self.rwlock_spin_rounds = rwlock_spin_rounds
        # Indices whether multi-index scanning was enabled. Valid values:
        # 
        # * **0:** Multi-index scanning was disabled.
        # * **1:** Multi-index scanning was enabled.
        self.rwlock_spin_waits = rwlock_spin_waits
        # The average number of joins that performed table scans without using indexes.
        # 
        # > If the value of this parameter is not 0, check the table indexes.
        self.select_full_join_avg = select_full_join_avg
        # The average number of joins that selected a range.
        self.select_full_range_join_avg = select_full_range_join_avg
        # The average selected range.
        self.select_range_avg = select_range_avg
        # The average number of scanned rows.
        self.select_scan_avg = select_scan_avg
        # The semi-synchronous replication latency. Unit: millisecond.
        self.semisync_delay_time = semisync_delay_time
        # The amount of time consumed for locking the server. Unit: millisecond.
        self.server_lock_time = server_lock_time
        # The number of merges that the sorting algorithm must perform.
        self.sort_merge_passes = sort_merge_passes
        # The average number of sorts that were performed by using a range.
        self.sort_range_avg = sort_range_avg
        # The average number of sorted rows.
        self.sort_rows_avg = sort_rows_avg
        # The average number of sorts that were performed during table scans.
        self.sort_scan_avg = sort_scan_avg
        # The SQL template ID.
        self.sql_id = sql_id
        # The type of the SQL statement. Valid values:
        # 
        # * **SELECT**
        # * **UPDATE**
        # * **DELETE**
        self.sql_type = sql_type
        # The names of tables in the database.
        self.tables = tables
        # The reserved parameter.
        self.timer_wait_avg = timer_wait_avg
        # The data timestamp. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        # The number of on-disk temporary tables.
        self.tmp_disk_tables = tmp_disk_tables
        # The average number of on-disk temporary tables.
        self.tmp_disk_tables_avg = tmp_disk_tables_avg
        # The number of temporary tables.
        self.tmp_tables = tmp_tables
        # The average number of temporary tables.
        self.tmp_tables_avg = tmp_tables_avg
        # The execution latency. Unit: millisecond.
        self.total_latency = total_latency
        # The amount of time consumed for locking the storage transaction. Unit: millisecond.
        self.transaction_lock_time = transaction_lock_time
        # The user ID.
        self.user_id = user_id
        # The number of warnings.
        self.warn_count = warn_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_latency is not None:
            result['AvgLatency'] = self.avg_latency

        if self.count is not None:
            result['Count'] = self.count

        if self.count_rate is not None:
            result['CountRate'] = self.count_rate

        if self.cpu_rate is not None:
            result['CpuRate'] = self.cpu_rate

        if self.cpu_time is not None:
            result['CpuTime'] = self.cpu_time

        if self.data_read_time is not None:
            result['DataReadTime'] = self.data_read_time

        if self.data_reads is not None:
            result['DataReads'] = self.data_reads

        if self.data_write_time is not None:
            result['DataWriteTime'] = self.data_write_time

        if self.data_writes is not None:
            result['DataWrites'] = self.data_writes

        if self.db is not None:
            result['Db'] = self.db

        if self.elapsed_time is not None:
            result['ElapsedTime'] = self.elapsed_time

        if self.err_count is not None:
            result['ErrCount'] = self.err_count

        if self.first_time is not None:
            result['FirstTime'] = self.first_time

        if self.full_scan is not None:
            result['FullScan'] = self.full_scan

        if self.id is not None:
            result['Id'] = self.id

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.last_time is not None:
            result['LastTime'] = self.last_time

        if self.lock_latency_avg is not None:
            result['LockLatencyAvg'] = self.lock_latency_avg

        if self.logic_id is not None:
            result['LogicId'] = self.logic_id

        if self.logic_reads is not None:
            result['LogicReads'] = self.logic_reads

        if self.max_latency is not None:
            result['MaxLatency'] = self.max_latency

        if self.mutex_spins is not None:
            result['MutexSpins'] = self.mutex_spins

        if self.mutex_waits is not None:
            result['MutexWaits'] = self.mutex_waits

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.physical_async_reads is not None:
            result['PhysicalAsyncReads'] = self.physical_async_reads

        if self.physical_reads is not None:
            result['PhysicalReads'] = self.physical_reads

        if self.psql is not None:
            result['Psql'] = self.psql

        if self.redo_writes is not None:
            result['RedoWrites'] = self.redo_writes

        if self.rows_affected is not None:
            result['RowsAffected'] = self.rows_affected

        if self.rows_affected_avg is not None:
            result['RowsAffectedAvg'] = self.rows_affected_avg

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_examined_avg is not None:
            result['RowsExaminedAvg'] = self.rows_examined_avg

        if self.rows_send_avg is not None:
            result['RowsSendAvg'] = self.rows_send_avg

        if self.rows_sent is not None:
            result['RowsSent'] = self.rows_sent

        if self.rows_sent_avg is not None:
            result['RowsSentAvg'] = self.rows_sent_avg

        if self.rows_sorted is not None:
            result['RowsSorted'] = self.rows_sorted

        if self.rt_rate is not None:
            result['RtRate'] = self.rt_rate

        if self.rwlock_os_waits is not None:
            result['RwlockOsWaits'] = self.rwlock_os_waits

        if self.rwlock_spin_rounds is not None:
            result['RwlockSpinRounds'] = self.rwlock_spin_rounds

        if self.rwlock_spin_waits is not None:
            result['RwlockSpinWaits'] = self.rwlock_spin_waits

        if self.select_full_join_avg is not None:
            result['SelectFullJoinAvg'] = self.select_full_join_avg

        if self.select_full_range_join_avg is not None:
            result['SelectFullRangeJoinAvg'] = self.select_full_range_join_avg

        if self.select_range_avg is not None:
            result['SelectRangeAvg'] = self.select_range_avg

        if self.select_scan_avg is not None:
            result['SelectScanAvg'] = self.select_scan_avg

        if self.semisync_delay_time is not None:
            result['SemisyncDelayTime'] = self.semisync_delay_time

        if self.server_lock_time is not None:
            result['ServerLockTime'] = self.server_lock_time

        if self.sort_merge_passes is not None:
            result['SortMergePasses'] = self.sort_merge_passes

        if self.sort_range_avg is not None:
            result['SortRangeAvg'] = self.sort_range_avg

        if self.sort_rows_avg is not None:
            result['SortRowsAvg'] = self.sort_rows_avg

        if self.sort_scan_avg is not None:
            result['SortScanAvg'] = self.sort_scan_avg

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.tables is not None:
            result['Tables'] = self.tables

        if self.timer_wait_avg is not None:
            result['TimerWaitAvg'] = self.timer_wait_avg

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.tmp_disk_tables is not None:
            result['TmpDiskTables'] = self.tmp_disk_tables

        if self.tmp_disk_tables_avg is not None:
            result['TmpDiskTablesAvg'] = self.tmp_disk_tables_avg

        if self.tmp_tables is not None:
            result['TmpTables'] = self.tmp_tables

        if self.tmp_tables_avg is not None:
            result['TmpTablesAvg'] = self.tmp_tables_avg

        if self.total_latency is not None:
            result['TotalLatency'] = self.total_latency

        if self.transaction_lock_time is not None:
            result['TransactionLockTime'] = self.transaction_lock_time

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.warn_count is not None:
            result['WarnCount'] = self.warn_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgLatency') is not None:
            self.avg_latency = m.get('AvgLatency')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('CountRate') is not None:
            self.count_rate = m.get('CountRate')

        if m.get('CpuRate') is not None:
            self.cpu_rate = m.get('CpuRate')

        if m.get('CpuTime') is not None:
            self.cpu_time = m.get('CpuTime')

        if m.get('DataReadTime') is not None:
            self.data_read_time = m.get('DataReadTime')

        if m.get('DataReads') is not None:
            self.data_reads = m.get('DataReads')

        if m.get('DataWriteTime') is not None:
            self.data_write_time = m.get('DataWriteTime')

        if m.get('DataWrites') is not None:
            self.data_writes = m.get('DataWrites')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('ElapsedTime') is not None:
            self.elapsed_time = m.get('ElapsedTime')

        if m.get('ErrCount') is not None:
            self.err_count = m.get('ErrCount')

        if m.get('FirstTime') is not None:
            self.first_time = m.get('FirstTime')

        if m.get('FullScan') is not None:
            self.full_scan = m.get('FullScan')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('LastTime') is not None:
            self.last_time = m.get('LastTime')

        if m.get('LockLatencyAvg') is not None:
            self.lock_latency_avg = m.get('LockLatencyAvg')

        if m.get('LogicId') is not None:
            self.logic_id = m.get('LogicId')

        if m.get('LogicReads') is not None:
            self.logic_reads = m.get('LogicReads')

        if m.get('MaxLatency') is not None:
            self.max_latency = m.get('MaxLatency')

        if m.get('MutexSpins') is not None:
            self.mutex_spins = m.get('MutexSpins')

        if m.get('MutexWaits') is not None:
            self.mutex_waits = m.get('MutexWaits')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('PhysicalAsyncReads') is not None:
            self.physical_async_reads = m.get('PhysicalAsyncReads')

        if m.get('PhysicalReads') is not None:
            self.physical_reads = m.get('PhysicalReads')

        if m.get('Psql') is not None:
            self.psql = m.get('Psql')

        if m.get('RedoWrites') is not None:
            self.redo_writes = m.get('RedoWrites')

        if m.get('RowsAffected') is not None:
            self.rows_affected = m.get('RowsAffected')

        if m.get('RowsAffectedAvg') is not None:
            self.rows_affected_avg = m.get('RowsAffectedAvg')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsExaminedAvg') is not None:
            self.rows_examined_avg = m.get('RowsExaminedAvg')

        if m.get('RowsSendAvg') is not None:
            self.rows_send_avg = m.get('RowsSendAvg')

        if m.get('RowsSent') is not None:
            self.rows_sent = m.get('RowsSent')

        if m.get('RowsSentAvg') is not None:
            self.rows_sent_avg = m.get('RowsSentAvg')

        if m.get('RowsSorted') is not None:
            self.rows_sorted = m.get('RowsSorted')

        if m.get('RtRate') is not None:
            self.rt_rate = m.get('RtRate')

        if m.get('RwlockOsWaits') is not None:
            self.rwlock_os_waits = m.get('RwlockOsWaits')

        if m.get('RwlockSpinRounds') is not None:
            self.rwlock_spin_rounds = m.get('RwlockSpinRounds')

        if m.get('RwlockSpinWaits') is not None:
            self.rwlock_spin_waits = m.get('RwlockSpinWaits')

        if m.get('SelectFullJoinAvg') is not None:
            self.select_full_join_avg = m.get('SelectFullJoinAvg')

        if m.get('SelectFullRangeJoinAvg') is not None:
            self.select_full_range_join_avg = m.get('SelectFullRangeJoinAvg')

        if m.get('SelectRangeAvg') is not None:
            self.select_range_avg = m.get('SelectRangeAvg')

        if m.get('SelectScanAvg') is not None:
            self.select_scan_avg = m.get('SelectScanAvg')

        if m.get('SemisyncDelayTime') is not None:
            self.semisync_delay_time = m.get('SemisyncDelayTime')

        if m.get('ServerLockTime') is not None:
            self.server_lock_time = m.get('ServerLockTime')

        if m.get('SortMergePasses') is not None:
            self.sort_merge_passes = m.get('SortMergePasses')

        if m.get('SortRangeAvg') is not None:
            self.sort_range_avg = m.get('SortRangeAvg')

        if m.get('SortRowsAvg') is not None:
            self.sort_rows_avg = m.get('SortRowsAvg')

        if m.get('SortScanAvg') is not None:
            self.sort_scan_avg = m.get('SortScanAvg')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('Tables') is not None:
            self.tables = m.get('Tables')

        if m.get('TimerWaitAvg') is not None:
            self.timer_wait_avg = m.get('TimerWaitAvg')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('TmpDiskTables') is not None:
            self.tmp_disk_tables = m.get('TmpDiskTables')

        if m.get('TmpDiskTablesAvg') is not None:
            self.tmp_disk_tables_avg = m.get('TmpDiskTablesAvg')

        if m.get('TmpTables') is not None:
            self.tmp_tables = m.get('TmpTables')

        if m.get('TmpTablesAvg') is not None:
            self.tmp_tables_avg = m.get('TmpTablesAvg')

        if m.get('TotalLatency') is not None:
            self.total_latency = m.get('TotalLatency')

        if m.get('TransactionLockTime') is not None:
            self.transaction_lock_time = m.get('TransactionLockTime')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('WarnCount') is not None:
            self.warn_count = m.get('WarnCount')

        return self

